@@ -8,7 +8,6 @@ from shapely.wkb import loads
 from shapely.geometry import Point, Polygon, LineString, MultiLineString
 from shapely.ops import unary_union, polygonize
 import PySimpleGUI as sg
-import warnings
 
 class latin_design:
     
@@ -18,7 +17,7 @@ class latin_design:
         if self.point.crs is None:
             self.point.crs = {'init': 'epsg:3857'}
         self.point.to_crs({'init': 'epsg:3857'})
-        warnings.filterwarnings("ignore")
+        pd.options.mode.chained_assignment = None
         self.buffer_length = buffer_length
         xcords = self.point.geometry.x
         ycords = self.point.geometry.y
@@ -49,7 +48,7 @@ class select_geoms:
         
         self.gdf_path = gdf_path
         self.length = length
-        warnings.filterwarnings("ignore")
+        pd.options.mode.chained_assignment = None
         if isinstance(self.gdf_path, str):
             try:
                 data = pd.concat([gpd.read_file(shp).to_crs({'init': 'epsg:3857'}) for shp in [i for i in glob.glob(f"{self.gdf_path}/*.shp")]]).pipe(gpd.GeoDataFrame)
@@ -137,32 +136,6 @@ class select_geoms:
             self.TestPlot = None
             pass
 
-
-class check_topology:
-    
-    def __init__(self, gdf:gpd.GeoDataFrame):
-        
-        self.gdf = gdf
-        warnings.filterwarnings("ignore")
-        gdf = gdf.copy()
-        val_data = gpd.GeoDataFrame()
-        for index, row in tqdm(gdf.iterrows(), total = gdf.shape[0]):
-            if row['geometry'].is_valid == False | row['geometry'].is_simple == False:
-                deci = sg.PopupYesNo("Do you want to fix the geometry?")
-                if deci == 'Yes':
-                    pol = row['geometry'].buffer(0)
-                    mid = gpd.GeoDataFrame(geometry=gpd.GeoSeries(pol))
-                    val_data = val_data.append(mid)
-                else:
-                    break
-            else:
-                val = gpd.GeoDataFrame(geometry=gpd.GeoSeries(row['geometry']))
-                val_data = val_data.append(val)
-        if val_data.crs == None:
-            val_data.crs = {'init': 'epsg:4326'}
-        self.topology = val_data
-
-
 class rotate_plot:
     
     def __init__(self, aux_data, plot:gpd.GeoDataFrame, attribute:str):
@@ -170,7 +143,7 @@ class rotate_plot:
         self.aux_data = aux_data
         self.plot = plot
         self.attribute = attribute
-        warnings.filterwarnings("ignore")
+        pd.options.mode.chained_assignment = None
         xmax, ymin, xmin, ymax= self.plot.total_bounds
         if isinstance(self.aux_data, gpd.GeoDataFrame):
             
@@ -200,33 +173,14 @@ class rotate_plot:
             pass
 
 
-class check_crs:
-    
-    def __init__(self,
-                 gdf
-                 ):
-        
-        self.gdf = gdf
-        warnings.filterwarnings("ignore")
-        if isinstance(gdf, gpd.GeoDataFrame):
-            if gdf.crs == None:
-                gdf.crs = {'init': 'epsg: 4326'}
-            self.geosolution = gdf
-        elif isinstance(gdf, str):
-            data = gpd.read_file(gdf)
-            if data.crs == None:
-                data.crs = {'init': 'epsg: 4326'}
-            self.geosolution = data
-        else:
-            pass
-
 class composite_union:
     
     def __init__(self, data, buffer = None):
         
         self.data = data
         self.buffer = buffer
-        warnings.filterwarnings("ignore")
+        
+        pd.options.mode.chained_assignment = None
         if data.crs == {'init': 'epsg: 4326'} and buffer == None:
             unary_data = gpd.GeoDataFrame(
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
@@ -270,4 +224,33 @@ class composite_union:
             
         else:
             self.geosolution = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])))
-            self.centroid = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])).centroid)
\ No newline at end of file
+            self.centroid = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])).centroid)
+
+class check_topology:
+    
+    def __init__(self, data):
+        
+        self.data = data
+        pd.options.mode.chained_assignment = None
+        if isinstance(data, str):
+            gdf = gpd.read_file(self.data)
+        elif isinstance(data, gpd.GeoDataFrame):
+            gdf = self.data
+        else:
+            pass
+        val_data = gpd.GeoDataFrame()
+        for index, row in tqdm(gdf.iterrows(), total = gdf.shape[0]):
+            if row['geometry'].is_valid == False | row['geometry'].is_simple == False:
+                deci = sg.PopupYesNo("Do you want to fix the geometry?")
+                if deci == 'Yes':
+                    pol = row['geometry'].buffer(0)
+                    mid = gpd.GeoDataFrame(geometry=gpd.GeoSeries(pol))
+                    val_data = val_data.append(mid)
+                else:
+                    break
+            else:
+                val = gpd.GeoDataFrame(geometry=gpd.GeoSeries(row['geometry']))
+                val_data = val_data.append(val)
+        if val_data.crs == None:
+            val_data.crs = {'init': 'epsg:4326'}
+        self.geosolution = val_data
\ No newline at end of file
